Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(872)

Unified Diff: base/test/launcher/test_results_tracker.h

Issue 2411003003: Save an early test summary in case the test launcher crashes or gets killed (Closed)
Patch Set: Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/test/launcher/test_launcher.cc ('k') | base/test/launcher/test_results_tracker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/test/launcher/test_results_tracker.h
diff --git a/base/test/launcher/test_results_tracker.h b/base/test/launcher/test_results_tracker.h
index 8910f7371a2bb1deaf6ea4c322d09ec64bb6676f..64e5319b192a0f83eb5912fb531be114f84bec80 100644
--- a/base/test/launcher/test_results_tracker.h
+++ b/base/test/launcher/test_results_tracker.h
@@ -61,9 +61,12 @@ class TestResultsTracker {
// conditions that affect the entire test run, as opposed to individual tests.
void AddGlobalTag(const std::string& tag);
// Saves a JSON summary of all test iterations results to |path|. Returns
// true on success.
- bool SaveSummaryAsJSON(const FilePath& path) const WARN_UNUSED_RESULT;
+ bool SaveSummaryAsJSON(
+ const FilePath& path,
+ const std::vector<std::string>& additional_tags) const WARN_UNUSED_RESULT;
// Map where keys are test result statuses, and values are sets of tests
// which finished with that status.
« no previous file with comments | « base/test/launcher/test_launcher.cc ('k') | base/test/launcher/test_results_tracker.cc » ('j') | no next file with comments »
@@ -61,9 +61,12 @@ class TestResultsTracker {
// conditions that affect the entire test run, as opposed to individual tests.
void AddGlobalTag(const std::string& tag);
- // Saves a JSON summary of all test iterations results to |path|. Returns
+ // Saves a JSON summary of all test iterations results to |path|. Adds
+ // |additional_tags| to the summary (just for this invocation). Returns
// true on success.

Powered by Google App Engine
This is Rietveld 408576698